@@ -2,19 +2,13 @@ import subprocess
 from pathlib import Path
 
 import click
-from kedro.framework.context import load_context
+from kedro.framework.cli.utils import _add_src_to_path
+from kedro.framework.project import configure_project
+from kedro.framework.session import KedroSession
+from kedro.framework.startup import _get_project_metadata, _is_project
 
 from kedro_mlflow.framework.cli.cli_utils import write_jinja_template
 from kedro_mlflow.framework.context import get_mlflow_config
-from kedro_mlflow.utils import _is_kedro_project
-
-try:
-    from kedro.framework.context import get_static_project_data
-except ImportError:  # pragma: no cover
-    from kedro_mlflow.utils import (
-        _get_project_globals as get_static_project_data,  # pragma: no cover
-    )
-
 
 TEMPLATE_FOLDER_PATH = Path(__file__).parent.parent.parent / "template" / "project"
 
@@ -24,7 +18,7 @@ class KedroClickGroup(click.Group):
         self.commands = {}
 
         # add commands on the fly based on conditions
-        if _is_kedro_project():
+        if _is_project(Path.cwd()):
             self.add_command(init)
             self.add_command(ui)
             # self.add_command(run) # TODO : IMPLEMENT THIS FUNCTION
@@ -65,7 +59,7 @@ def mlflow_commands():
     "-f",
     is_flag=True,
     default=False,
-    help="Update the template without any checks. If a 'mlflow.yml' already eists, it will be overridden.",
+    help="Update the template without any checks.",
 )
 @click.option(
     "--silent",
@@ -76,19 +70,26 @@ def mlflow_commands():
 )
 def init(env, force, silent):
     """Updates the template of a kedro project.
-    Running this command is mandatory to use kedro-mlflow. This
-    adds a configuration file used for run parametrization when
-    calling "kedro run" command.
+    Running this command is mandatory to use kedro-mlflow.
+    This adds "conf/base/mlflow.yml": This is a configuration file
+    used for run parametrization when calling "kedro run" command.
+    See INSERT_DOC_URL for further details.
     """
 
     # get constants
     mlflow_yml = "mlflow.yml"
     project_path = Path().cwd()
-    project_globals = get_static_project_data(project_path)
-    context = load_context(project_path)
+    project_metadata = _get_project_metadata(project_path)
+    _add_src_to_path(project_metadata.source_dir, project_path)
+    configure_project(project_metadata.package_name)
+    session = KedroSession.create(
+        project_metadata.package_name, project_path=project_path
+    )
+    context = session.load_context()
     mlflow_yml_path = project_path / context.CONF_ROOT / env / mlflow_yml
 
-    # mlflow.yml is just a static file
+    # mlflow.yml is just a static file,
+    # but the name of the experiment is set to be the same as the project
     if mlflow_yml_path.is_file() and not force:
         click.secho(
             click.style(
@@ -96,14 +97,13 @@ def init(env, force, silent):
                 fg="red",
             )
         )
-        return 1
     else:
         try:
             write_jinja_template(
                 src=TEMPLATE_FOLDER_PATH / mlflow_yml,
                 is_cookiecutter=False,
                 dst=mlflow_yml_path,
-                python_package=project_globals["package_name"],
+                python_package=project_metadata.package_name,
             )
         except FileNotFoundError:
             click.secho(
@@ -112,7 +112,6 @@ def init(env, force, silent):
                     fg="red",
                 )
             )
-            return 1
         if not silent:
             click.secho(
                 click.style(
@@ -120,7 +119,6 @@ def init(env, force, silent):
                     fg="green",
                 )
             )
-        return 0
 
 
 @mlflow_commands.command()
@@ -131,23 +129,52 @@ def init(env, force, silent):
     default="local",
     help="The environment within conf folder we want to retrieve.",
 )
-def ui(env):
+@click.option(
+    "--port",
+    "-p",
+    required=False,
+    help="The port to listen on",
+)
+@click.option(
+    "--host",
+    "-h",
+    required=False,
+    help="The network address to listen on (default: 127.0.0.1). Use 0.0.0.0 to bind to all addresses if you want to access the tracking server from other machines.",
+)
+def ui(env, port, host):
     """Opens the mlflow user interface with the
     project-specific settings of mlflow.yml. This interface
     enables to browse and compares runs.
-
     """
 
     project_path = Path().cwd()
-    context = load_context(project_path=project_path, env=env)
-    # the context must contains the self.mlflow attribues with mlflow configuration
-    mlflow_conf = get_mlflow_config(context)
+    project_metadata = _get_project_metadata(project_path)
+    _add_src_to_path(project_metadata.source_dir, project_path)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        package_name=project_metadata.package_name,
+        project_path=project_path,
+        env=env,
+    ):
 
-    # call mlflow ui with specific options
-    # TODO : add more options for ui
-    subprocess.call(
-        ["mlflow", "ui", "--backend-store-uri", mlflow_conf.mlflow_tracking_uri]
-    )
+        mlflow_conf = get_mlflow_config()
+        host = host or mlflow_conf.ui_opts.get("host")
+        port = port or mlflow_conf.ui_opts.get("port")
+
+        # call mlflow ui with specific options
+        # TODO : add more options for ui
+        subprocess.call(
+            [
+                "mlflow",
+                "ui",
+                "--backend-store-uri",
+                mlflow_conf.mlflow_tracking_uri,
+                "--host",
+                host,
+                "--port",
+                port,
+            ]
+        )
 
 
 @mlflow_commands.command()
