@@ -1,5 +1,7 @@
+from typing import Optional
+
 from kedro.config import MissingConfigException
-from kedro.framework.context import KedroContext
+from kedro.framework.session import KedroSession, get_current_session
 
 from kedro_mlflow.framework.context.config import (
     KedroMlflowConfig,
@@ -10,7 +12,9 @@ from kedro_mlflow.framework.context.config import (
 # this could be a read-only property in the context
 # with a @property decorator
 # but for consistency with hook system, it is an external function
-def get_mlflow_config(context: KedroContext):
+def get_mlflow_config(session: Optional[KedroSession] = None):
+    session = session or get_current_session()
+    context = session.load_context()
     try:
         conf_mlflow_yml = context.config_loader.get("mlflow*", "mlflow*/**")
     except MissingConfigException:
