@@ -1,3 +1,4 @@
+import logging
 import sys
 from pathlib import Path
 from tempfile import TemporaryDirectory
@@ -5,7 +6,6 @@ from typing import Any, Dict, Union
 
 import mlflow
 import yaml
-from kedro.framework.context import load_context
 from kedro.framework.hooks import hook_impl
 from kedro.io import DataCatalog
 from kedro.pipeline import Pipeline
@@ -14,6 +14,8 @@ from mlflow.entities import RunStatus
 from mlflow.models import infer_signature
 
 from kedro_mlflow.framework.context import get_mlflow_config
+from kedro_mlflow.framework.hooks.utils import _assert_mlflow_enabled
+from kedro_mlflow.io.catalog.switch_catalog_logging import switch_catalog_logging
 from kedro_mlflow.io.metrics import MlflowMetricsDataSet
 from kedro_mlflow.mlflow import KedroPipelineModel
 from kedro_mlflow.pipeline.pipeline_ml import PipelineML
@@ -22,7 +24,7 @@ from kedro_mlflow.utils import _parse_requirements
 
 class MlflowPipelineHook:
     def __init__(self):
-        self.context = None
+        self._is_mlflow_enabled = True
 
     @hook_impl
     def after_catalog_created(
@@ -35,6 +37,7 @@ class MlflowPipelineHook:
         load_versions: str,
         run_id: str,
     ):
+
         for name, dataset in catalog._data_sets.items():
             if isinstance(dataset, MlflowMetricsDataSet) and dataset._prefix is None:
                 if dataset._run_id is not None:
@@ -70,44 +73,46 @@ class MlflowPipelineHook:
             pipeline: The ``Pipeline`` that will be run.
             catalog: The ``DataCatalog`` to be used during the run.
         """
-        self.context = load_context(
-            project_path=run_params["project_path"],
-            env=run_params["env"],
-            extra_params=run_params["extra_params"],
-        )
+        self._is_mlflow_enabled = _assert_mlflow_enabled(run_params["pipeline_name"])
 
-        mlflow_conf = get_mlflow_config(self.context)
-        mlflow_conf.setup(self.context)
+        if self._is_mlflow_enabled:
+            mlflow_conf = get_mlflow_config()
+            mlflow_conf.setup()
 
-        run_name = (
-            mlflow_conf.run_opts["name"]
-            if mlflow_conf.run_opts["name"] is not None
-            else run_params["pipeline_name"]
-        )
-        mlflow.start_run(
-            run_id=mlflow_conf.run_opts["id"],
-            experiment_id=mlflow_conf.experiment.experiment_id,
-            run_name=run_name,
-            nested=mlflow_conf.run_opts["nested"],
-        )
-        # Set tags only for run parameters that have values.
-        mlflow.set_tags({k: v for k, v in run_params.items() if v})
-        # add manually git sha for consistency with the journal
-        # TODO : this does not take into account not committed files, so it
-        # does not ensure reproducibility. Define what to do.
-        mlflow.set_tag("git_sha", _git_sha(run_params["project_path"]))
-        mlflow.set_tag(
-            "kedro_command",
-            _generate_kedro_command(
-                tags=run_params["tags"],
-                node_names=run_params["node_names"],
-                from_nodes=run_params["from_nodes"],
-                to_nodes=run_params["to_nodes"],
-                from_inputs=run_params["from_inputs"],
-                load_versions=run_params["load_versions"],
-                pipeline_name=run_params["pipeline_name"],
-            ),
-        )
+            run_name = (
+                mlflow_conf.run_opts["name"]
+                if mlflow_conf.run_opts["name"] is not None
+                else run_params["pipeline_name"]
+            )
+            mlflow.start_run(
+                run_id=mlflow_conf.run_opts["id"],
+                experiment_id=mlflow_conf.experiment.experiment_id,
+                run_name=run_name,
+                nested=mlflow_conf.run_opts["nested"],
+            )
+            # Set tags only for run parameters that have values.
+            mlflow.set_tags({k: v for k, v in run_params.items() if v})
+            # add manually git sha for consistency with the journal
+            # TODO : this does not take into account not committed files, so it
+            # does not ensure reproducibility. Define what to do.
+            mlflow.set_tag("git_sha", _git_sha(run_params["project_path"]))
+            mlflow.set_tag(
+                "kedro_command",
+                _generate_kedro_command(
+                    tags=run_params["tags"],
+                    node_names=run_params["node_names"],
+                    from_nodes=run_params["from_nodes"],
+                    to_nodes=run_params["to_nodes"],
+                    from_inputs=run_params["from_inputs"],
+                    load_versions=run_params["load_versions"],
+                    pipeline_name=run_params["pipeline_name"],
+                ),
+            )
+        else:
+            logging.info(
+                "kedro-mlflow logging is deactivated for this pipeline in the configuration. This includes DataSets and parameters."
+            )
+            switch_catalog_logging(catalog, False)
 
     @hook_impl
     def after_pipeline_run(
@@ -138,35 +143,37 @@ class MlflowPipelineHook:
             pipeline: The ``Pipeline`` that was run.
             catalog: The ``DataCatalog`` used during the run.
         """
+        if self._is_mlflow_enabled:
+            if isinstance(pipeline, PipelineML):
+                with TemporaryDirectory() as tmp_dir:
+                    # This will be removed at the end of the context manager,
+                    # but we need to log in mlflow beforeremoving the folder
+                    pipeline_catalog = pipeline._extract_pipeline_catalog(catalog)
+                    artifacts = pipeline.extract_pipeline_artifacts(
+                        pipeline_catalog, temp_folder=Path(tmp_dir)
+                    )
 
-        if isinstance(pipeline, PipelineML):
-            with TemporaryDirectory() as tmp_dir:
-                # This will be removed at the end of the context manager,
-                # but we need to log in mlflow beforeremoving the folder
-                pipeline_catalog = pipeline._extract_pipeline_catalog(catalog)
-                artifacts = pipeline.extract_pipeline_artifacts(
-                    pipeline_catalog, temp_folder=Path(tmp_dir)
-                )
+                    if pipeline.model_signature == "auto":
+                        input_data = pipeline_catalog.load(pipeline.input_name)
+                        model_signature = infer_signature(model_input=input_data)
+                    else:
+                        model_signature = pipeline.model_signature
 
-                if pipeline.model_signature == "auto":
-                    input_data = pipeline_catalog.load(pipeline.input_name)
-                    model_signature = infer_signature(model_input=input_data)
-                else:
-                    model_signature = pipeline.model_signature
-
-                mlflow.pyfunc.log_model(
-                    artifact_path=pipeline.model_name,
-                    python_model=KedroPipelineModel(
-                        pipeline_ml=pipeline,
-                        catalog=pipeline_catalog,
-                        **pipeline.kwargs,
-                    ),
-                    artifacts=artifacts,
-                    conda_env=_format_conda_env(pipeline.conda_env),
-                    signature=model_signature,
-                )
-        # Close the mlflow active run at the end of the pipeline to avoid interactions with further runs
-        mlflow.end_run()
+                    mlflow.pyfunc.log_model(
+                        artifact_path=pipeline.model_name,
+                        python_model=KedroPipelineModel(
+                            pipeline_ml=pipeline,
+                            catalog=pipeline_catalog,
+                            **pipeline.kwargs,
+                        ),
+                        artifacts=artifacts,
+                        conda_env=_format_conda_env(pipeline.conda_env),
+                        signature=model_signature,
+                    )
+            # Close the mlflow active run at the end of the pipeline to avoid interactions with further runs
+            mlflow.end_run()
+        else:
+            switch_catalog_logging(catalog, True)
 
     @hook_impl
     def on_pipeline_error(
@@ -201,9 +208,13 @@ class MlflowPipelineHook:
             pipeline: (Not used) The ``Pipeline`` that will was run.
             catalog: (Not used) The ``DataCatalog`` used during the run.
         """
-
-        while mlflow.active_run():
-            mlflow.end_run(RunStatus.to_string(RunStatus.FAILED))
+        if self._is_mlflow_enabled:
+            while mlflow.active_run():
+                mlflow.end_run(RunStatus.to_string(RunStatus.FAILED))
+        else:  # pragma: no cover
+            # the catalog is supposed to be reloaded each time with _get_catalog,
+            # hence it should not be modified. this is only a safeguard
+            switch_catalog_logging(catalog, True)
 
 
 mlflow_pipeline_hook = MlflowPipelineHook()
