@@ -14,6 +14,7 @@ def pipeline_ml_factory(
     conda_env: Optional[Union[str, Path, Dict[str, Any]]] = None,
     model_name: Optional[str] = "model",
     model_signature: Union[ModelSignature, str, None] = "auto",
+    **kwargs
 ) -> PipelineML:
     """This function is a helper to create `PipelineML`
     object directly from two Kedro `Pipelines` (one of
@@ -49,12 +50,19 @@ def pipeline_ml_factory(
             the folder where the model will be stored in
             remote mlflow. Defaults to "model".
         model_signature (Union[ModelSignature, bool]): The mlflow
-             signature of the input dataframe common to training
-             and inference.
-                   - If 'auto', it is infered automatically
-                   - If None, no signature is used
-                   - if a `ModelSignature` instance, passed
-                   to the underlying dataframe
+            signature of the input dataframe common to training
+            and inference.
+                - If 'auto', it is infered automatically
+                - If None, no signature is used
+                - if a `ModelSignature` instance, passed
+                to the underlying dataframe
+        kwargs:
+            extra arguments to be passed to `KedroPipelineModel`
+            when the PipelineML object is automatically saved at the end of a run.
+            This includes:
+                - `copy_mode`: the copy_mode to be used for underlying dataset
+                when loaded in memory
+                - `runner`: the kedro runner to run the model with
 
     Returns:
         PipelineML: A `PipelineML` which is automatically
@@ -70,5 +78,6 @@ def pipeline_ml_factory(
         conda_env=conda_env,
         model_name=model_name,
         model_signature=model_signature,
+        **kwargs
     )
     return pipeline
