@@ -3,7 +3,10 @@ import os
 import mlflow
 import pytest
 import yaml
-from kedro.context import load_context
+from kedro.framework.cli.utils import _add_src_to_path
+from kedro.framework.project import configure_project
+from kedro.framework.session import KedroSession
+from kedro.framework.startup import _get_project_metadata
 from mlflow.tracking import MlflowClient
 
 from kedro_mlflow.framework.context.config import (
@@ -49,14 +52,14 @@ def test_kedro_mlflow_config_init_wrong_path(tmp_path):
         KedroMlflowConfig(project_path=tmp_path)
 
 
-def test_kedro_mlflow_config_init(tmp_path):
-    # create a ".kedro.yml" file to identify "tmp_path" as the root of a kedro project
-    (tmp_path / ".kedro.yml").write_text(yaml.dump(dict(context_path="fake/path")))
+def test_kedro_mlflow_config_init(kedro_project_with_mlflow_conf):
+    # kedro_project_with_mlflow_conf is a global fixture in conftest
 
-    config = KedroMlflowConfig(project_path=tmp_path)
+    config = KedroMlflowConfig(project_path=kedro_project_with_mlflow_conf)
     assert config.to_dict() == dict(
-        mlflow_tracking_uri=(tmp_path / "mlruns").as_uri(),
+        mlflow_tracking_uri=(kedro_project_with_mlflow_conf / "mlruns").as_uri(),
         credentials=None,
+        disable_tracking=KedroMlflowConfig.DISABLE_TRACKING_OPTS,
         experiments=KedroMlflowConfig.EXPERIMENT_OPTS,
         run=KedroMlflowConfig.RUN_OPTS,
         ui=KedroMlflowConfig.UI_OPTS,
@@ -64,57 +67,67 @@ def test_kedro_mlflow_config_init(tmp_path):
     )
 
 
-def test_kedro_mlflow_config_bad_long_parameters_strategy(tmp_path):
+def test_kedro_mlflow_config_bad_long_parameters_strategy(
+    kedro_project_with_mlflow_conf,
+):
     # create a ".kedro.yml" file to identify "tmp_path" as the root of a kedro project
-    (tmp_path / ".kedro.yml").write_text(yaml.dump(dict(context_path="fake/path")))
     with pytest.raises(
         KedroMlflowConfigError, match="'long_parameters_strategy' must be one of "
     ):
         KedroMlflowConfig(
-            project_path=tmp_path,
+            project_path=kedro_project_with_mlflow_conf,
             node_hook_opts=dict(long_parameters_strategy="does_not_exist"),
         )
 
 
 def test_kedro_mlflow_config_new_experiment_does_not_exists(
-    mocker, tmp_path, config_dir
+    kedro_project_with_mlflow_conf,
 ):
-    # create a ".kedro.yml" file to identify "tmp_path" as the root of a kedro project
-    mocker.patch("kedro_mlflow.utils._is_kedro_project", return_value=True)
 
     config = KedroMlflowConfig(
-        project_path=tmp_path,
+        project_path=kedro_project_with_mlflow_conf,
         mlflow_tracking_uri="mlruns",
         experiment_opts=dict(name="exp1"),
     )
-    context = load_context(tmp_path)
-    config.setup(context)
+
+    project_metadata = _get_project_metadata(kedro_project_with_mlflow_conf)
+    _add_src_to_path(project_metadata.source_dir, kedro_project_with_mlflow_conf)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        "fake_project", project_path=kedro_project_with_mlflow_conf
+    ):
+        config.setup()
+
     assert "exp1" in [exp.name for exp in config.mlflow_client.list_experiments()]
 
 
-def test_kedro_mlflow_config_experiment_exists(mocker, tmp_path, config_dir):
-    # create a ".kedro.yml" file to identify "tmp_path" as the root of a kedro project
-    mocker.patch("kedro_mlflow.utils._is_kedro_project", return_value=True)
+def test_kedro_mlflow_config_experiment_exists(mocker, kedro_project_with_mlflow_conf):
 
     # create an experiment with the same name
-    mlflow_tracking_uri = (tmp_path / "mlruns").as_uri()
+    mlflow_tracking_uri = (
+        kedro_project_with_mlflow_conf / "conf" / "local" / "mlruns"
+    ).as_uri()
     MlflowClient(mlflow_tracking_uri).create_experiment("exp1")
     config = KedroMlflowConfig(
-        project_path=tmp_path,
+        project_path=kedro_project_with_mlflow_conf,
         mlflow_tracking_uri="mlruns",
         experiment_opts=dict(name="exp1"),
     )
-    context = load_context(tmp_path)
-    config.setup(context)
+
+    project_metadata = _get_project_metadata(kedro_project_with_mlflow_conf)
+    _add_src_to_path(project_metadata.source_dir, kedro_project_with_mlflow_conf)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        "fake_project", project_path=kedro_project_with_mlflow_conf
+    ):
+        config.setup()
     assert "exp1" in [exp.name for exp in config.mlflow_client.list_experiments()]
 
 
-def test_kedro_mlflow_config_experiment_was_deleted(mocker, tmp_path, config_dir):
-    # create a ".kedro.yml" file to identify "tmp_path" as the root of a kedro project
-    mocker.patch("kedro_mlflow.utils._is_kedro_project", lambda x: True)
+def test_kedro_mlflow_config_experiment_was_deleted(kedro_project_with_mlflow_conf):
 
     # create an experiment with the same name and then delete it
-    mlflow_tracking_uri = (tmp_path / "mlruns").as_uri()
+    mlflow_tracking_uri = (kedro_project_with_mlflow_conf / "mlruns").as_uri()
     mlflow_client = MlflowClient(mlflow_tracking_uri)
     mlflow_client.create_experiment("exp1")
     mlflow_client.delete_experiment(
@@ -123,75 +136,99 @@ def test_kedro_mlflow_config_experiment_was_deleted(mocker, tmp_path, config_dir
 
     # the config must restore properly the experiment
     config = KedroMlflowConfig(
-        project_path=tmp_path,
+        project_path=kedro_project_with_mlflow_conf,
         mlflow_tracking_uri="mlruns",
         experiment_opts=dict(name="exp1"),
     )
-    context = load_context(tmp_path)
-    config.setup(context)
+
+    project_metadata = _get_project_metadata(kedro_project_with_mlflow_conf)
+    _add_src_to_path(project_metadata.source_dir, kedro_project_with_mlflow_conf)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        "fake_project", project_path=kedro_project_with_mlflow_conf
+    ):
+        config.setup()
+
     assert "exp1" in [exp.name for exp in config.mlflow_client.list_experiments()]
 
 
-def test_kedro_mlflow_config_setup_set_tracking_uri(mocker, tmp_path, config_dir):
-    # create a ".kedro.yml" file to identify "tmp_path" as the root of a kedro project
-    mocker.patch("kedro_mlflow.utils._is_kedro_project", lambda x: True)
+def test_kedro_mlflow_config_setup_set_tracking_uri(kedro_project_with_mlflow_conf):
 
     # create an experiment with the same name and then delete it
-    mlflow_tracking_uri = (tmp_path / "awesome_tracking").as_uri()
+    mlflow_tracking_uri = (kedro_project_with_mlflow_conf / "awesome_tracking").as_uri()
 
     # the config must restore properly the experiment
     config = KedroMlflowConfig(
-        project_path=tmp_path,
+        project_path=kedro_project_with_mlflow_conf,
         mlflow_tracking_uri="awesome_tracking",
         experiment_opts=dict(name="exp1"),
     )
-    context = load_context(tmp_path)
-    config.setup(context)
+
+    project_metadata = _get_project_metadata(kedro_project_with_mlflow_conf)
+    _add_src_to_path(project_metadata.source_dir, kedro_project_with_mlflow_conf)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        "fake_project", project_path=kedro_project_with_mlflow_conf
+    ):
+        config.setup()
 
     assert mlflow.get_tracking_uri() == mlflow_tracking_uri
 
 
-def test_kedro_mlflow_config_setup_export_credentials(mocker, tmp_path, config_dir):
-    # create a ".kedro.yml" file to identify "tmp_path" as the root of a kedro project
-    mocker.patch("kedro_mlflow.utils._is_kedro_project", lambda x: True)
+def test_kedro_mlflow_config_setup_export_credentials(kedro_project_with_mlflow_conf):
 
-    (tmp_path / "conf/base/credentials.yml").write_text(
+    (kedro_project_with_mlflow_conf / "conf/base/credentials.yml").write_text(
         yaml.dump(dict(my_mlflow_creds=dict(fake_mlflow_cred="my_fake_cred")))
     )
 
     # the config must restore properly the experiment
-    config = KedroMlflowConfig(project_path=tmp_path, credentials="my_mlflow_creds")
-    context = load_context(tmp_path)
-    config.setup(context)
+    config = KedroMlflowConfig(
+        project_path=kedro_project_with_mlflow_conf, credentials="my_mlflow_creds"
+    )
+
+    project_metadata = _get_project_metadata(kedro_project_with_mlflow_conf)
+    _add_src_to_path(project_metadata.source_dir, kedro_project_with_mlflow_conf)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        "fake_project", project_path=kedro_project_with_mlflow_conf
+    ):
+        config.setup()
 
     assert os.environ["fake_mlflow_cred"] == "my_fake_cred"
 
 
-def test_kedro_mlflow_config_setup_tracking_priority(mocker, tmp_path, config_dir):
+def test_kedro_mlflow_config_setup_tracking_priority(kedro_project_with_mlflow_conf):
     """Test if the mlflow_tracking uri set is the one of mlflow.yml
     if it also eist in credentials.
 
     Args:
         mocker ([type]): [description]
         tmp_path ([type]): [description]
-        config_dir ([type]): [description]
     """
     # create a ".kedro.yml" file to identify "tmp_path" as the root of a kedro project
-    mocker.patch("kedro_mlflow.utils._is_kedro_project", lambda x: True)
 
-    (tmp_path / "conf/base/credentials.yml").write_text(
+    (kedro_project_with_mlflow_conf / "conf/base/credentials.yml").write_text(
         yaml.dump(dict(my_mlflow_creds=dict(mlflow_tracking_uri="mlruns2")))
     )
 
     config = KedroMlflowConfig(
-        project_path=tmp_path,
+        project_path=kedro_project_with_mlflow_conf,
         mlflow_tracking_uri="mlruns1",
         credentials="my_mlflow_creds",
     )
-    context = load_context(tmp_path)
-    config.setup(context)
 
-    assert mlflow.get_tracking_uri() == (tmp_path / "mlruns1").as_uri()
+    project_metadata = _get_project_metadata(kedro_project_with_mlflow_conf)
+    _add_src_to_path(project_metadata.source_dir, kedro_project_with_mlflow_conf)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        "fake_project", project_path=kedro_project_with_mlflow_conf
+    ):
+        config.setup()
+
+    assert (
+        mlflow.get_tracking_uri()
+        == (kedro_project_with_mlflow_conf / "mlruns1").as_uri()
+    )
 
 
 @pytest.mark.parametrize(
@@ -202,27 +239,27 @@ def test_kedro_mlflow_config_setup_tracking_priority(mocker, tmp_path, config_di
         (r"file:///C:/fake/path/mlruns"),  # local uri
     ],
 )
-def test_kedro_mlflow_config_validate_uri_local(mocker, tmp_path, uri):
-    mocker.patch("kedro_mlflow.utils._is_kedro_project", return_value=True)
+def test_kedro_mlflow_config_validate_uri_local(
+    mocker, kedro_project_with_mlflow_conf, uri
+):
     mocker.patch("mlflow.tracking.MlflowClient", return_value=None)
     mocker.patch(
         "kedro_mlflow.framework.context.config.KedroMlflowConfig._get_or_create_experiment",
         return_value=None,
     )
 
-    config = KedroMlflowConfig(project_path=tmp_path)
+    config = KedroMlflowConfig(project_path=kedro_project_with_mlflow_conf)
     assert config._validate_uri(uri=uri).startswith(r"file:///")  # relative
 
 
-def test_from_dict_to_dict_idempotent(mocker, tmp_path):
-    mocker.patch("kedro_mlflow.utils._is_kedro_project", return_value=True)
+def test_from_dict_to_dict_idempotent(mocker, kedro_project_with_mlflow_conf):
     mocker.patch("mlflow.tracking.MlflowClient", return_value=None)
     mocker.patch(
         "kedro_mlflow.framework.context.config.KedroMlflowConfig._get_or_create_experiment",
         return_value=None,
     )
 
-    config = KedroMlflowConfig(project_path=tmp_path)
+    config = KedroMlflowConfig(project_path=kedro_project_with_mlflow_conf)
     original_config_dict = config.to_dict()
     # modify config
     config.from_dict(original_config_dict)
