@@ -4,6 +4,10 @@ from typing import Dict
 import mlflow
 import pytest
 import yaml
+from kedro.framework.cli.utils import _add_src_to_path
+from kedro.framework.project import configure_project
+from kedro.framework.session import KedroSession
+from kedro.framework.startup import _get_project_metadata
 from kedro.io import DataCatalog, MemoryDataSet
 from kedro.pipeline import Pipeline, node
 from mlflow.tracking import MlflowClient
@@ -105,28 +109,36 @@ def dummy_catalog():
 
 
 def test_pipeline_run_hook_getting_configs(
-    tmp_path, config_dir, monkeypatch, dummy_run_params, dummy_pipeline, dummy_catalog
+    kedro_project,
+    dummy_run_params,
+    dummy_pipeline,
+    dummy_catalog,
 ):
 
-    monkeypatch.chdir(tmp_path)
-
     _write_yaml(
-        tmp_path / "conf" / "base" / "mlflow.yml",
+        kedro_project / "conf" / "local" / "mlflow.yml",
         dict(
             hooks=dict(node=dict(flatten_dict_params=True, recursive=False, sep="-")),
         ),
     ),
 
-    mlflow_node_hook = MlflowNodeHook()
-    mlflow_node_hook.before_pipeline_run(
-        run_params=dummy_run_params, pipeline=dummy_pipeline, catalog=dummy_catalog
-    )
+    project_metadata = _get_project_metadata(kedro_project)
+    _add_src_to_path(project_metadata.source_dir, kedro_project)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        package_name=project_metadata.package_name,
+        project_path=kedro_project,
+    ):
+        mlflow_node_hook = MlflowNodeHook()
+        mlflow_node_hook.before_pipeline_run(
+            run_params=dummy_run_params, pipeline=dummy_pipeline, catalog=dummy_catalog
+        )
 
-    assert (
-        mlflow_node_hook.flatten,
-        mlflow_node_hook.recursive,
-        mlflow_node_hook.sep,
-    ) == (True, False, "-")
+        assert (
+            mlflow_node_hook.flatten,
+            mlflow_node_hook.recursive,
+            mlflow_node_hook.sep,
+        ) == (True, False, "-")
 
 
 @pytest.mark.parametrize(
@@ -137,21 +149,15 @@ def test_pipeline_run_hook_getting_configs(
     ],
 )
 def test_node_hook_logging(
-    tmp_path,
-    mocker,
-    monkeypatch,
+    kedro_project,
     dummy_run_params,
     dummy_catalog,
     dummy_pipeline,
     dummy_node,
-    config_dir,
     flatten_dict_params,
     expected,
 ):
 
-    mocker.patch("logging.config.dictConfig")
-    mocker.patch("kedro_mlflow.utils._is_kedro_project", return_value=True)
-    monkeypatch.chdir(tmp_path)
     # config = KedroMlflowConfig(
     #     project_path=tmp_path,
     #     node_hook_opts={"flatten_dict_params": flatten_dict_params, "sep": "-"},
@@ -163,7 +169,7 @@ def test_node_hook_logging(
     # )
 
     _write_yaml(
-        tmp_path / "conf" / "base" / "mlflow.yml",
+        kedro_project / "conf" / "base" / "mlflow.yml",
         dict(
             hooks=dict(
                 node=dict(
@@ -179,24 +185,34 @@ def test_node_hook_logging(
         v: dummy_catalog._data_sets.get(v) for k, v in dummy_node._inputs.items()
     }
 
-    mlflow_tracking_uri = (tmp_path / "mlruns").as_uri()
-    mlflow.set_tracking_uri(mlflow_tracking_uri)
-    with mlflow.start_run():
-        mlflow_node_hook.before_pipeline_run(
-            run_params=dummy_run_params, pipeline=dummy_pipeline, catalog=dummy_catalog
-        )
-        mlflow_node_hook.before_node_run(
-            node=dummy_node,
-            catalog=dummy_catalog,
-            inputs=node_inputs,
-            is_async=False,
-            run_id="132",
-        )
-        run_id = mlflow.active_run().info.run_id
+    mlflow_tracking_uri = (kedro_project / "mlruns").as_uri()
 
-    mlflow_client = MlflowClient(mlflow_tracking_uri)
-    current_run = mlflow_client.get_run(run_id)
-    assert current_run.data.params == expected
+    project_metadata = _get_project_metadata(kedro_project)
+    _add_src_to_path(project_metadata.source_dir, kedro_project)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        package_name=project_metadata.package_name,
+        project_path=kedro_project,
+    ):
+        mlflow.set_tracking_uri(mlflow_tracking_uri)
+        with mlflow.start_run():
+            mlflow_node_hook.before_pipeline_run(
+                run_params=dummy_run_params,
+                pipeline=dummy_pipeline,
+                catalog=dummy_catalog,
+            )
+            mlflow_node_hook.before_node_run(
+                node=dummy_node,
+                catalog=dummy_catalog,
+                inputs=node_inputs,
+                is_async=False,
+                run_id="132",
+            )
+            run_id = mlflow.active_run().info.run_id
+
+        mlflow_client = MlflowClient(mlflow_tracking_uri)
+        current_run = mlflow_client.get_run(run_id)
+        assert current_run.data.params == expected
 
 
 @pytest.mark.parametrize(
@@ -204,19 +220,17 @@ def test_node_hook_logging(
 )
 @pytest.mark.parametrize("strategy", ["fail", "truncate", "tag"])
 def test_node_hook_logging_below_limit_all_strategy(
-    tmp_path, config_dir, dummy_run_params, dummy_node, param_length, strategy
+    kedro_project, dummy_run_params, param_length, strategy
 ):
 
-    # mocker.patch("kedro_mlflow.utils._is_kedro_project", return_value=True)
-
     _write_yaml(
-        tmp_path / "conf" / "base" / "mlflow.yml",
+        kedro_project / "conf" / "local" / "mlflow.yml",
         dict(
             hooks=dict(node=dict(long_parameters_strategy=strategy)),
         ),
     )
 
-    mlflow_tracking_uri = (tmp_path / "mlruns").as_uri()
+    mlflow_tracking_uri = (kedro_project / "mlruns").as_uri()
     mlflow.set_tracking_uri(mlflow_tracking_uri)
 
     mlflow_node_hook = MlflowNodeHook()
@@ -224,107 +238,19 @@ def test_node_hook_logging_below_limit_all_strategy(
     param_value = param_length * "a"
     node_inputs = {"params:my_param": param_value}
 
-    with mlflow.start_run():
-        mlflow_node_hook.before_pipeline_run(
-            run_params=dummy_run_params, pipeline=Pipeline([]), catalog=DataCatalog()
-        )
-        mlflow_node_hook.before_node_run(
-            node=node(func=lambda x: x, inputs=dict(x="a"), outputs=None),
-            catalog=DataCatalog(),  # can be empty
-            inputs=node_inputs,
-            is_async=False,
-            run_id="132",
-        )
-        run_id = mlflow.active_run().info.run_id
-
-    mlflow_client = MlflowClient(mlflow_tracking_uri)
-    current_run = mlflow_client.get_run(run_id)
-    assert current_run.data.params == {"my_param": param_value}
-
-
-@pytest.mark.parametrize(
-    "param_length",
-    [MAX_PARAM_VAL_LENGTH + 20],
-)
-def test_node_hook_logging_above_limit_truncate_strategy(
-    tmp_path, config_dir, dummy_run_params, dummy_node, param_length
-):
-
-    # mocker.patch("kedro_mlflow.utils._is_kedro_project", return_value=True)
-
-    _write_yaml(
-        tmp_path / "conf" / "base" / "mlflow.yml",
-        dict(
-            hooks=dict(node=dict(long_parameters_strategy="truncate")),
-        ),
-    )
-
-    mlflow_tracking_uri = (tmp_path / "mlruns").as_uri()
-    mlflow.set_tracking_uri(mlflow_tracking_uri)
-
-    mlflow_node_hook = MlflowNodeHook()
-
-    param_value = param_length * "a"
-    node_inputs = {"params:my_param": param_value}
-
-    with mlflow.start_run():
-        mlflow_node_hook.before_pipeline_run(
-            run_params=dummy_run_params, pipeline=Pipeline([]), catalog=DataCatalog()
-        )
-        mlflow_node_hook.before_node_run(
-            node=node(func=lambda x: x, inputs=dict(x="a"), outputs=None),
-            catalog=DataCatalog(),  # can be empty
-            inputs=node_inputs,
-            is_async=False,
-            run_id="132",
-        )
-        run_id = mlflow.active_run().info.run_id
-
-    mlflow_client = MlflowClient(mlflow_tracking_uri)
-    current_run = mlflow_client.get_run(run_id)
-    assert current_run.data.params == {"my_param": param_value[0:MAX_PARAM_VAL_LENGTH]}
-
-
-@pytest.mark.parametrize(
-    "param_length",
-    [MAX_PARAM_VAL_LENGTH + 20],
-)
-def test_node_hook_logging_above_limit_fail_strategy(
-    tmp_path, config_dir, dummy_run_params, dummy_node, param_length
-):
-
-    # mocker.patch("kedro_mlflow.utils._is_kedro_project", return_value=True)
-
-    _write_yaml(
-        tmp_path / "conf" / "base" / "mlflow.yml",
-        dict(
-            hooks=dict(node=dict(long_parameters_strategy="fail")),
-        ),
-    )
-
-    mlflow_tracking_uri = (tmp_path / "mlruns").as_uri()
-    mlflow.set_tracking_uri(mlflow_tracking_uri)
-
-    mlflow_node_hook = MlflowNodeHook()
-
-    param_value = param_length * "a"
-    node_inputs = {"params:my_param": param_value}
-
-    with mlflow.start_run():
-        mlflow_node_hook.before_pipeline_run(
-            run_params=dummy_run_params, pipeline=Pipeline([]), catalog=DataCatalog()
-        )
-
-        # IMPORTANT: Overpassing the parameters limit
-        # should raise an error for all mlflow backend
-        # but it does not on FileStore backend :
-        # https://github.com/mlflow/mlflow/issues/2814#issuecomment-628284425
-        # Since we use FileStore system for simplicty for tests logging works
-        # But we have enforced failure (which is slightly different from mlflow
-        # behaviour)
-        with pytest.raises(
-            ValueError, match=f"Parameter 'my_param' length is {param_length}"
-        ):
+    project_metadata = _get_project_metadata(kedro_project)
+    _add_src_to_path(project_metadata.source_dir, kedro_project)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        package_name=project_metadata.package_name,
+        project_path=kedro_project,
+    ):
+        with mlflow.start_run():
+            mlflow_node_hook.before_pipeline_run(
+                run_params=dummy_run_params,
+                pipeline=Pipeline([]),
+                catalog=DataCatalog(),
+            )
             mlflow_node_hook.before_node_run(
                 node=node(func=lambda x: x, inputs=dict(x="a"), outputs=None),
                 catalog=DataCatalog(),  # can be empty
@@ -332,26 +258,29 @@ def test_node_hook_logging_above_limit_fail_strategy(
                 is_async=False,
                 run_id="132",
             )
+            run_id = mlflow.active_run().info.run_id
+
+        mlflow_client = MlflowClient(mlflow_tracking_uri)
+        current_run = mlflow_client.get_run(run_id)
+        assert current_run.data.params == {"my_param": param_value}
 
 
 @pytest.mark.parametrize(
     "param_length",
     [MAX_PARAM_VAL_LENGTH + 20],
 )
-def test_node_hook_logging_above_limit_tag_strategy(
-    tmp_path, config_dir, dummy_run_params, dummy_node, param_length
+def test_node_hook_logging_above_limit_truncate_strategy(
+    kedro_project, dummy_run_params, param_length
 ):
 
-    # mocker.patch("kedro_mlflow.utils._is_kedro_project", return_value=True)
-
     _write_yaml(
-        tmp_path / "conf" / "base" / "mlflow.yml",
+        kedro_project / "conf" / "local" / "mlflow.yml",
         dict(
-            hooks=dict(node=dict(long_parameters_strategy="tag")),
+            hooks=dict(node=dict(long_parameters_strategy="truncate")),
         ),
     )
 
-    mlflow_tracking_uri = (tmp_path / "mlruns").as_uri()
+    mlflow_tracking_uri = (kedro_project / "mlruns").as_uri()
     mlflow.set_tracking_uri(mlflow_tracking_uri)
 
     mlflow_node_hook = MlflowNodeHook()
@@ -359,30 +288,147 @@ def test_node_hook_logging_above_limit_tag_strategy(
     param_value = param_length * "a"
     node_inputs = {"params:my_param": param_value}
 
-    with mlflow.start_run():
-        mlflow_node_hook.before_pipeline_run(
-            run_params=dummy_run_params, pipeline=Pipeline([]), catalog=DataCatalog()
-        )
+    project_metadata = _get_project_metadata(kedro_project)
+    _add_src_to_path(project_metadata.source_dir, kedro_project)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        package_name=project_metadata.package_name,
+        project_path=kedro_project,
+    ):
+        with mlflow.start_run():
+            mlflow_node_hook.before_pipeline_run(
+                run_params=dummy_run_params,
+                pipeline=Pipeline([]),
+                catalog=DataCatalog(),
+            )
+            mlflow_node_hook.before_node_run(
+                node=node(func=lambda x: x, inputs=dict(x="a"), outputs=None),
+                catalog=DataCatalog(),  # can be empty
+                inputs=node_inputs,
+                is_async=False,
+                run_id="132",
+            )
+            run_id = mlflow.active_run().info.run_id
 
-        # IMPORTANT: Overpassing the parameters limit
-        # should raise an error for all mlflow backend
-        # but it does not on FileStore backend :
-        # https://github.com/mlflow/mlflow/issues/2814#issuecomment-628284425
-        # Since we use FileStore system for simplicty for tests logging works
-        # But we have enforced failure (which is slightly different from mlflow
-        # behaviour)
-        mlflow_node_hook.before_node_run(
-            node=node(func=lambda x: x, inputs=dict(x="a"), outputs=None),
-            catalog=DataCatalog(),  # can be empty
-            inputs=node_inputs,
-            is_async=False,
-            run_id="132",
-        )
-        run_id = mlflow.active_run().info.run_id
+        mlflow_client = MlflowClient(mlflow_tracking_uri)
+        current_run = mlflow_client.get_run(run_id)
+        assert current_run.data.params == {
+            "my_param": param_value[0:MAX_PARAM_VAL_LENGTH]
+        }
 
-    mlflow_client = MlflowClient(mlflow_tracking_uri)
-    current_run = mlflow_client.get_run(run_id)
-    assert current_run.data.params == {}
-    assert {
-        k: v for k, v in current_run.data.tags.items() if not k.startswith("mlflow")
-    } == {"my_param": param_value}
+
+@pytest.mark.parametrize(
+    "param_length",
+    [MAX_PARAM_VAL_LENGTH + 20],
+)
+def test_node_hook_logging_above_limit_fail_strategy(
+    kedro_project, dummy_run_params, param_length
+):
+
+    _write_yaml(
+        kedro_project / "conf" / "local" / "mlflow.yml",
+        dict(
+            hooks=dict(node=dict(long_parameters_strategy="fail")),
+        ),
+    )
+
+    mlflow_tracking_uri = (kedro_project / "mlruns").as_uri()
+    mlflow.set_tracking_uri(mlflow_tracking_uri)
+
+    mlflow_node_hook = MlflowNodeHook()
+
+    param_value = param_length * "a"
+    node_inputs = {"params:my_param": param_value}
+
+    project_metadata = _get_project_metadata(kedro_project)
+    _add_src_to_path(project_metadata.source_dir, kedro_project)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        package_name=project_metadata.package_name,
+        project_path=kedro_project,
+    ):
+        with mlflow.start_run():
+            mlflow_node_hook.before_pipeline_run(
+                run_params=dummy_run_params,
+                pipeline=Pipeline([]),
+                catalog=DataCatalog(),
+            )
+
+            # IMPORTANT: Overpassing the parameters limit
+            # should raise an error for all mlflow backend
+            # but it does not on FileStore backend :
+            # https://github.com/mlflow/mlflow/issues/2814#issuecomment-628284425
+            # Since we use FileStore system for simplicty for tests logging works
+            # But we have enforced failure (which is slightly different from mlflow
+            # behaviour)
+            with pytest.raises(
+                ValueError, match=f"Parameter 'my_param' length is {param_length}"
+            ):
+                mlflow_node_hook.before_node_run(
+                    node=node(func=lambda x: x, inputs=dict(x="a"), outputs=None),
+                    catalog=DataCatalog(),  # can be empty
+                    inputs=node_inputs,
+                    is_async=False,
+                    run_id="132",
+                )
+
+
+@pytest.mark.parametrize(
+    "param_length",
+    [MAX_PARAM_VAL_LENGTH + 20],
+)
+def test_node_hook_logging_above_limit_tag_strategy(
+    kedro_project, dummy_run_params, param_length
+):
+
+    _write_yaml(
+        kedro_project / "conf" / "local" / "mlflow.yml",
+        dict(
+            hooks=dict(node=dict(long_parameters_strategy="tag")),
+        ),
+    )
+
+    mlflow_tracking_uri = (kedro_project / "mlruns").as_uri()
+    mlflow.set_tracking_uri(mlflow_tracking_uri)
+
+    mlflow_node_hook = MlflowNodeHook()
+
+    param_value = param_length * "a"
+    node_inputs = {"params:my_param": param_value}
+
+    project_metadata = _get_project_metadata(kedro_project)
+    _add_src_to_path(project_metadata.source_dir, kedro_project)
+    configure_project(project_metadata.package_name)
+    with KedroSession.create(
+        package_name=project_metadata.package_name,
+        project_path=kedro_project,
+    ):
+        with mlflow.start_run():
+            mlflow_node_hook.before_pipeline_run(
+                run_params=dummy_run_params,
+                pipeline=Pipeline([]),
+                catalog=DataCatalog(),
+            )
+
+            # IMPORTANT: Overpassing the parameters limit
+            # should raise an error for all mlflow backend
+            # but it does not on FileStore backend :
+            # https://github.com/mlflow/mlflow/issues/2814#issuecomment-628284425
+            # Since we use FileStore system for simplicty for tests logging works
+            # But we have enforced failure (which is slightly different from mlflow
+            # behaviour)
+            mlflow_node_hook.before_node_run(
+                node=node(func=lambda x: x, inputs=dict(x="a"), outputs=None),
+                catalog=DataCatalog(),  # can be empty
+                inputs=node_inputs,
+                is_async=False,
+                run_id="132",
+            )
+            run_id = mlflow.active_run().info.run_id
+
+        mlflow_client = MlflowClient(mlflow_tracking_uri)
+        current_run = mlflow_client.get_run(run_id)
+        assert current_run.data.params == {}
+        assert {
+            k: v for k, v in current_run.data.tags.items() if not k.startswith("mlflow")
+        } == {"my_param": param_value}
